@@ -10,7 +10,7 @@
 
 #include "adw-style-manager-private.h"
 
-#include "adw-macros-private.h"
+#include "adw-main-private.h"
 #include "adw-settings-private.h"
 #include <gtk/gtk.h>
 
@@ -29,8 +29,6 @@
  * @ADW_COLOR_SCHEME_FORCE_DARK: Always use dark appearance.
  *
  * Application color schemes for [property@StyleManager:color-scheme].
- *
- * Since: 1.0
  */
 
 /**
@@ -44,8 +42,6 @@
  * It allows to set the color scheme via the
  * [property@StyleManager:color-scheme] property, and to query the current
  * appearance, as well as whether a system-wide color scheme preference exists.
- *
- * Since: 1.0
  */
 
 struct _AdwStyleManager
@@ -257,7 +253,7 @@ adw_style_manager_constructed (GObject *object)
                              self,
                              G_CONNECT_SWAPPED);
 
-    if (!g_getenv ("GTK_THEME")) {
+    if (!adw_is_granite_present () && !g_getenv ("GTK_THEME")) {
       g_object_set (gtk_settings_get_for_display (self->display),
                     "gtk-theme-name", "Adwaita-empty",
                     NULL);
@@ -387,8 +383,6 @@ adw_style_manager_class_init (AdwStyleManagerClass *klass)
    *
    * The display will be `NULL` for the style manager returned by
    * [func@StyleManager.get_default].
-   *
-   * Since: 1.0
    */
   props[PROP_DISPLAY] =
     g_param_spec_object ("display", NULL, NULL,
@@ -429,8 +423,6 @@ adw_style_manager_class_init (AdwStyleManagerClass *klass)
    * The [property@StyleManager:system-supports-color-schemes] property can be
    * used to check if the current environment provides a color scheme
    * preference.
-   *
-   * Since: 1.0
    */
   props[PROP_COLOR_SCHEME] =
     g_param_spec_enum ("color-scheme", NULL, NULL,
@@ -448,8 +440,6 @@ adw_style_manager_class_init (AdwStyleManagerClass *klass)
    * separate appearance switcher if it's set to `FALSE`.
    *
    * See [property@StyleManager:color-scheme].
-   *
-   * Since: 1.0
    */
   props[PROP_SYSTEM_SUPPORTS_COLOR_SCHEMES] =
     g_param_spec_boolean ("system-supports-color-schemes", NULL, NULL,
@@ -463,8 +453,6 @@ adw_style_manager_class_init (AdwStyleManagerClass *klass)
    *
    * This property can be used to query the current appearance, as requested via
    * [property@StyleManager:color-scheme].
-   *
-   * Since: 1.0
    */
   props[PROP_DARK] =
     g_param_spec_boolean ("dark", NULL, NULL,
@@ -477,8 +465,6 @@ adw_style_manager_class_init (AdwStyleManagerClass *klass)
    * Whether the application is using high contrast appearance.
    *
    * This cannot be overridden by applications.
-   *
-   * Since: 1.0
    */
   props[PROP_HIGH_CONTRAST] =
     g_param_spec_boolean ("high-contrast", NULL, NULL,
@@ -534,8 +520,6 @@ adw_style_manager_ensure (void)
  * See [func@StyleManager.get_for_display].
  *
  * Returns: (transfer none): the default style manager
- *
- * Since: 1.0
  */
 AdwStyleManager *
 adw_style_manager_get_default (void)
@@ -558,8 +542,6 @@ adw_style_manager_get_default (void)
  * Most applications should use [func@StyleManager.get_default] instead.
  *
  * Returns: (transfer none): the style manager for @display
- *
- * Since: 1.0
  */
 AdwStyleManager *
 adw_style_manager_get_for_display (GdkDisplay *display)
@@ -584,8 +566,6 @@ adw_style_manager_get_for_display (GdkDisplay *display)
  * [func@StyleManager.get_default].
  *
  * Returns: (transfer none): (nullable): the display
- *
- * Since: 1.0
  */
 GdkDisplay *
 adw_style_manager_get_display (AdwStyleManager *self)
@@ -602,8 +582,6 @@ adw_style_manager_get_display (AdwStyleManager *self)
  * Gets the requested application color scheme.
  *
  * Returns: the color scheme
- *
- * Since: 1.0
  */
 AdwColorScheme
 adw_style_manager_get_color_scheme (AdwStyleManager *self)
@@ -649,8 +627,6 @@ adw_style_manager_get_color_scheme (AdwStyleManager *self)
  * The [property@StyleManager:system-supports-color-schemes] property can be
  * used to check if the current environment provides a color scheme
  * preference.
- *
- * Since: 1.0
  */
 void
 adw_style_manager_set_color_scheme (AdwStyleManager *self,
@@ -694,8 +670,6 @@ adw_style_manager_set_color_scheme (AdwStyleManager *self,
  * appearance switcher if it's set to `FALSE`.
  *
  * Returns: whether the system supports color schemes
- *
- * Since: 1.0
  */
 gboolean
 adw_style_manager_get_system_supports_color_schemes (AdwStyleManager *self)
@@ -715,8 +689,6 @@ adw_style_manager_get_system_supports_color_schemes (AdwStyleManager *self)
  * [property@StyleManager:color-scheme].
  *
  * Returns: whether the application is using dark appearance
- *
- * Since: 1.0
  */
 gboolean
 adw_style_manager_get_dark (AdwStyleManager *self)
@@ -735,8 +707,6 @@ adw_style_manager_get_dark (AdwStyleManager *self)
  * This cannot be overridden by applications.
  *
  * Returns: whether the application is using high contrast appearance
- *
- * Since: 1.0
  */
 gboolean
 adw_style_manager_get_high_contrast (AdwStyleManager *self)
