@@ -41,6 +41,10 @@ void adw_tab_box_setup_extra_drop_target (AdwTabBox     *self,
                                           GType         *types,
                                           gsize          n_types);
 
+gboolean adw_tab_box_get_extra_drag_preload (AdwTabBox *self);
+void     adw_tab_box_set_extra_drag_preload (AdwTabBox *self,
+                                             gboolean   preload);
+
 gboolean adw_tab_box_get_expand_tabs (AdwTabBox *self);
 void     adw_tab_box_set_expand_tabs (AdwTabBox *self,
                                       gboolean   expand_tabs);
